package main

import (
	"context"
	"os"
	"os/signal"

	_ "github.com/glebarez/go-sqlite"
	"github.com/go-telegram/bot"
	"github.com/go-telegram/bot/models"
)

func main() {
	ctx, cancel := signal.NotifyContext(context.Background(), os.Interrupt)
	defer cancel()

	if err := InitDb(); err != nil {
		panic(err)
	}
	defer db.Close()

	db.MustExec(schema)

	opts := []bot.Option{
		bot.WithMiddlewares(logChats, logUsers, checkRegistered),
		bot.WithDefaultHandler(defaultHandler),
	}

	b, err := bot.New(os.Getenv("TG_TOKEN"), opts...)
	if err != nil {
		panic(err)
	}

	b.RegisterHandler(bot.HandlerTypeMessageText, "/register", bot.MatchTypePrefix, registerChat)
	b.RegisterHandler(bot.HandlerTypeMessageText, "/ban", bot.MatchTypePrefix, banUser)
	b.RegisterHandlerMatchFunc(func(update *models.Update) bool {
		return update.Message != nil && len(update.Message.NewChatMembers) > 0
	}, handleNewJoined)
	b.Start(ctx)
}
